/* CODE_STYLE: default */
/* 可以将':'后的内容替换为其他 pygments.formatters.HtmlFormatter 参数 style 支持的样式 */

/* 在此输入你的样式，注意：
        - 不要用过于高级的 CSS 语法；
        - 不要用 CSS 变量；
 */
.md_content_to_mailify {
    max-width: 80%;
    margin: 1rem auto 15rem auto;
    padding: 20px 40px;
    border: 5px solid #00a549;
    border-radius: 20px;
    background-color: #f0eee6;
}


/*
 * 使用 :not(pre) > code 选择器，避免影响pre中的代码块
 * 只为行内代码（如在p, li标签中的code）添加背景
 */
:not(pre)>code {
    color: #0082f1;
    font-family: 'Source Code Pro';
    font-size: 85%;
    background-color: rgba(161, 161, 161, 0.502);
    border-radius: 6px;
    font-weight: bolder;
    padding: .1em .3em;
    margin: 0;
    white-space: break-spaces;
}


/* 调整代码块*/
pre:has(code) {
    border-radius: 10px;
    background-color: #F8F8F8;
    padding: 2%;
    overflow-x: auto;
}

h1 {
    border-bottom: 3px solid #FF6D2D;
}

/* KaTeX 渲染的字体大小 */
.katex {
    font-size: 1.2em;
}

a {
    color: #58a6ff;
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

/* 代码块内的代码不要有行内代码的灰框 */
div.container pre>code {
    background-color: transparent;
    font-weight: 600;
}